"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var enzyme_1 = require("enzyme");
var SideNav_1 = require("./SideNav");
var Nav_1 = require("react-sidenav/nav/Nav");
describe('<SideNav/>', function () {
    it('manages state internally if defaultSelectionPath is passed', function () {
        var wrapper = enzyme_1.mount((React.createElement(SideNav_1.SideNav, { defaultSelectedPath: '2' },
            React.createElement(Nav_1.Nav, { id: "1" }))));
        wrapper.find(Nav_1.Nav).simulate("click");
        expect(wrapper.state("selectedPath")).toBe("1");
    });
    it("calls onItemSelected listener when path is clicked", function () {
        var listener = jest.fn();
        var wrapper = enzyme_1.mount((React.createElement(SideNav_1.SideNav, { onItemSelection: listener, selectedPath: '1' },
            React.createElement(Nav_1.Nav, { id: "1" }))));
        wrapper.find(Nav_1.Nav).simulate("click");
        expect(listener.mock.calls.length).toBe(1);
        var arg = listener.mock.calls[0][0];
        expect(arg.path).toBe("1");
        expect(arg.id).toBe("1");
        expect(arg.payload).toBe(undefined);
    });
    it("calls onItemSelected with payload if Nav has payload", function () {
        var listener = jest.fn();
        var wrapper = enzyme_1.mount((React.createElement(SideNav_1.SideNav, { onItemSelection: listener, selectedPath: '1' },
            React.createElement(Nav_1.Nav, { id: "1", payload: "banana" }))));
        wrapper.find(Nav_1.Nav).simulate("click");
        expect(listener.mock.calls.length).toBe(1);
        var arg = listener.mock.calls[0][0];
        expect(arg.path).toBe("1");
        expect(arg.id).toBe("1");
        expect(arg.payload).toBe("banana");
    });
});
//# sourceMappingURL=SideNav.test.js.map